package stage

import (
	"log/slog"
)

func Run(stages []Stage) []StageResult {
	var parserResults []StageResult
	for _, stage := range stages {
		slog.Info("stage start", "name", stage.Name)
		slog.Info("executor run start", "cmd", stage.ExecutorCmd)
		executor := executorMap[stage.ExecutorName]
		executorResult, err := executor.Run(stage.ExecutorCmd)
		if err != nil {
			slog.Error("executor run error", "name", stage.ExecutorName, "error", err)
			break
		}
		slog.Info("executor run done", "result", executorResult)
		slog.Info("parser run start", "config", stage.ParserConfig)
		parser := parserMap[stage.ParserName]
		parserResult, err := parser.Run(executorResult, stage.ParserConfig)
		if err != nil {
			slog.Error("parser run error", "name", stage.ExecutorName, "error", err)
			break
		}
		slog.Info("parser run done", "result", parserResult)
		parserResults = append(parserResults, StageResult{
			Name:         stage.Name,
			ParserResult: parserResult,
		})
	}
	return parserResults
}

func Cleanup() {
	for name, executor := range executorMap {
		slog.Info("executor cleanup start", "name", name)
		err := executor.Cleanup()
		if err != nil {
			slog.Error("executor cleanup error", "name", name, "error", err)
		}
		slog.Info("executor cleanup done", "name", name)
	}
}
